/*
 * SimpleProducer.java
 *
 * Un SimpleProducer  in grado di inviare una sequenza di messaggi
 * ad una generica destinazione JMS (coda o argomento),
 * intervallati tra loro da un ritardo.
 *
 * I messaggi sono ricevuti da oggetti SynchConsumer (in modo sincrono)
 * oppure da AsynchConsumer (in modo asincrono).
 *
 * Variante di un esempio nel tutorial per Java EE.
 *
 * @author cabibbo
 */

package simpleproducer;

import javax.jms.*;

public class SimpleProducer {

    /* nome di questo producer */
    private String name;
    /* destinazione di questo producer */
    private Destination destination;
    /* connection factory di questo producer */
    private ConnectionFactory connectionFactory;

    /* connessione jms */
    private Connection connection = null;
    /* sessione jms */
    private Session session = null;

    /** Crea un nuovo SimpleProducer, di nome n, per una destinazione di nome dn. */
    public SimpleProducer(String n, Destination d, ConnectionFactory cf) {
        
        this.name = n;
        this.destination = d; 
        this.connectionFactory = cf; 
    }

    /** Apre la connessione alla destinazione JMS. */
    public void connect() {
        try {
            connection = connectionFactory.createConnection();
            session = connection.createSession(
                                false, // non transazionale
				Session.AUTO_ACKNOWLEDGE);
        } catch (Exception e) {
            System.out.println("Connection problem: " + e.toString());
            disconnect();
        }
    }

    /** Si disconnette dalla destinazione JMS. */
    public void disconnect() {
        if (connection != null) {
            try {
                connection.close();
                connection = null;
            } catch (JMSException e) {
                System.out.println("Disconnection problem: " + e.toString());
            }
        }
    }

    /** Invia un messaggio di testo text alla destinazione */
    public void sendMessage(String text) {
        try {
        	MessageProducer messageProducer = session.createProducer(destination);
        	TextMessage message = session.createTextMessage();
            message.setText(text);
            System.out.println("Sending message: " + message.getText());
            messageProducer.send(message);
	} catch (JMSException e) {
	    System.out.println("SimpleProducer: " + e.toString());
        }
    }

    /** Restituisce una descrizione di questo producer. */
    public String toString() {
        return "SimpleProducer[" +
                "name=" + name +
//                ", destination=" + destination.toString() +
                "]";

    }

}
